@@ -2,7 +2,7 @@
     copyright            : (C) 2002-2008 by Stefano Barbato
     email                : stefano@codesink.org
 
-    $Id: file_iterator.h,v 1.10 2008-10-07 11:06:26 tat Exp $
+    $Id: file_iterator.h,v 1.11 2008-10-27 18:30:42 tat Exp $
  ***************************************************************************/
 
 /***************************************************************************
@@ -85,7 +85,8 @@ bool ifile_iterator::operator!=(const ifile_iterator& right) const
 inline
 bool ifile_iterator::operator==(const ifile_iterator& right) const
 {
-    return m_eof == right.m_eof == 1;
+    // are equal if both are EOF
+    return (m_eof && right.m_eof);
 }
 
 }
