@@ -2,7 +2,7 @@
     copyright            : (C) 2002-2008 by Stefano Barbato
     email                : stefano@codesink.org
 
-    $Id: field.cxx,v 1.5 2008-10-07 11:06:26 tat Exp $
+    $Id: field.cxx,v 1.7 2009-02-27 15:56:34 tat Exp $
  ***************************************************************************/
 
 /***************************************************************************
@@ -157,6 +157,8 @@ std::ostream& operator<<(std::ostream& os, const Field& f)
 
 ostream& Field::write(ostream& os, unsigned int fold) const
 {
+    int in_quote, prev, skip;
+
     // default folding idiot-algorithm
     // override to customize
     if(fold)
@@ -164,23 +166,37 @@ ostream& Field::write(ostream& os, unsigned int fold) const
         int i, sp;
         string ostr = name() + ": " + value();
 
+        // skip the "fieldname: " part just on the first inner iteration 
+        skip = name().length() + 2; 
+
         while(ostr.length() > fold)
         {
-            for(i = name().length() + 2, sp = 0; i < ostr.length(); ++i)
+            prev = 0; // prev char processed 
+            in_quote = 0;
+            sp = 0;
+
+            for(i = skip; i < ostr.length(); ++i)
             {
-                if(isblank(ostr[i]))
+                if(ostr[i] == '"' && prev != '\\')
+                    in_quote = !in_quote;
+
+                if(!in_quote && isblank(ostr[i]))
                     sp = i; // last blank found
 
                 if(i >= fold && sp)
                 {
                     os.write(ostr.c_str(), sp);
-                    os << crlf << "\t";
                     ostr.erase(0, 1+sp);
+                    if(ostr.length() && !utils::string_is_blank(ostr))
+                        os << crlf << "\t"; // keep folding
                     break;
                 }
+
+                prev = ostr[i];
             }
             if(sp == 0)
                 break; // can't fold anymore
+            skip = 0; 
         }
 
         os << ostr;
