@@ -22,6 +22,7 @@ namespace mimetic
 
 using namespace std;
 
+
 /**
  * same as std::endl but NOT flush the buffer
  */
@@ -76,6 +77,15 @@ private:
 };
 
 
+bool string_is_blank(const std::string& s)
+{
+    size_t i, len = s.length();
+
+    for(i = 0; i < len; ++i)
+        if(!isblank(s[i]))
+            return false;
+    return true;
+}
 
 /// extract the filename from a fqn
 string extractFilename(const string& fqn)
