@@ -43,6 +43,9 @@ std::string extractFilename(const std::string&);
 /// returns a string representation of \p n
 std::string int2str(int n);
 
+/// return true if the string contains just blanks (space and tabs)
+bool string_is_blank(const std::string&);
+
 /// returns the integer value represented by \p s
 int str2int(const std::string& s);
 
