@@ -2,7 +2,7 @@
     copyright            : (C) 2003-2005 by Stefano Barbato
     email                : stefano@codesink.org
 
-    $Id: cutee.h,v 1.12 2007/04/03 08:13:22 tat Exp $
+    $Id: cutee.h,v 1.14 2008-10-07 15:43:55 tat Exp $
  ***************************************************************************/
 
 /***************************************************************************
@@ -99,6 +99,10 @@ typedef unsigned int uint;
 #define TEST_ASSERT_EQUALS_PM( a, b, m ) TEST_ASSERT_EX_M( (a == b), PRINT_ON_FAILURE_3( a, b, m ), __FILE__,__LINE__ )
 #define TEST_ASSERT_DIFFERS_PM( a, b, m ) TEST_ASSERT_EX_M( (a != b), PRINT_ON_FAILURE_3( a, b, m ), __FILE__,__LINE__)
 
+#define TEST_ASSERT_OR_RET(expr, msg) \
+    do { if(!expr) { TEST_ASSERT_M(expr, msg); return; } } while(0)
+
+
 namespace cutee // c++ unit testing environment 
 {
 
